@@ -3,11 +3,7 @@
 
 .fonctionMCMC <- function(data, x) {
 
-# .fonctionfit<- NULL
-# rm(.fonctionfit)
-
-
-return(.fonctionfit(x, temperatures=data$temperatures, 
+return(info.nests(parameters=x, temperatures=data$temperatures, 
                     derivate=data$derivate, weight=data$weight,
                     test=data$test, M0=data$M0, 
                     fixed.parameters=data$fixed.parameters))
